changeset 75141:e4abbe7f7417

(icalendar-import-buffer): Fix typo in docstring.
author Juanma Barranquero <lekktu@gmail.com>
date Mon, 08 Jan 2007 23:02:08 +0000
parents 6674b79afd5e
children 1e951eb6473e
files lisp/calendar/icalendar.el
diffstat 1 files changed, 5 insertions(+), 5 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/calendar/icalendar.el	Mon Jan 08 23:01:11 2007 +0000
+++ b/lisp/calendar/icalendar.el	Mon Jan 08 23:02:08 2007 +0000
@@ -709,7 +709,7 @@
   "Export diary file to iCalendar format.
 All diary entries in the file DIARY-FILENAME are converted to iCalendar
 format.  The result is appended to the file ICAL-FILENAME."
-  (interactive "FExport diary data from file: 
+  (interactive "FExport diary data from file:
 Finto iCalendar file: ")
   (save-current-buffer
     (set-buffer (find-file diary-filename))
@@ -1453,8 +1453,8 @@
 Argument DIARY-FILENAME input `diary-file'.
 Optional argument NON-MARKING determines whether events are created as
 non-marking or not."
-  (interactive "fImport iCalendar data from file: 
-Finto diary file: 
+  (interactive "fImport iCalendar data from file:
+Finto diary file:
 p")
   ;; clean up the diary file
   (save-current-buffer
@@ -1479,7 +1479,7 @@
 non-marking.
 
 Return code t means that importing worked well, return code nil
-means that an error has occured.  Error messages will be in the
+means that an error has occurred.  Error messages will be in the
 buffer `*icalendar-errors*'."
   (interactive)
   (save-current-buffer
@@ -1508,7 +1508,7 @@
                   (set-buffer b)
                   (save-buffer)))))
           (message "Converting icalendar...done")
           ;; return t if no error occured
           (not ical-errors))
       (message
        "Current buffer does not contain icalendar contents!")
@@ -1508,7 +1508,7 @@
                   (save-buffer)))))
           (message "Converting icalendar...done")
-          ;; return t if no error occured
+          ;; return t if no error occurred
           (not ical-errors))
       (message